##  Check the Session Details
  1. Select a test user with specific user group assignments, or add your own user to the AD user groups.
  2. Use a SAML tracer tool to inspect the SAML request and verify which attributes are sent. For details, see [Troubleshooting](https://help.sap.com/docs/leanix/ea/single-sign-on-sso?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cc8227a441014a371975e4b816f0a__troubleshooting).
If the SSO configuration is successful, access control entities are displayed.
